# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyApprovalStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyApprovalStatusValue = typing___NewType(
        "PolicyApprovalStatusValue", builtin___int
    )
    type___PolicyApprovalStatusValue = PolicyApprovalStatusValue
    PolicyApprovalStatus: _PolicyApprovalStatus
    class _PolicyApprovalStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyApprovalStatusEnum.PolicyApprovalStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 0
        )
        UNKNOWN = typing___cast(PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 1)
        DISAPPROVED = typing___cast(
            PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 2
        )
        APPROVED_LIMITED = typing___cast(
            PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 3
        )
        APPROVED = typing___cast(PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 4)
        AREA_OF_INTEREST_ONLY = typing___cast(
            PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 5
        )
    UNSPECIFIED = typing___cast(PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 0)
    UNKNOWN = typing___cast(PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 1)
    DISAPPROVED = typing___cast(PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 2)
    APPROVED_LIMITED = typing___cast(
        PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 3
    )
    APPROVED = typing___cast(PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 4)
    AREA_OF_INTEREST_ONLY = typing___cast(
        PolicyApprovalStatusEnum.PolicyApprovalStatusValue, 5
    )
    type___PolicyApprovalStatus = PolicyApprovalStatus
    def __init__(self,) -> None: ...

type___PolicyApprovalStatusEnum = PolicyApprovalStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PaymentModeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PaymentModeValue = typing___NewType("PaymentModeValue", builtin___int)
    type___PaymentModeValue = PaymentModeValue
    PaymentMode: _PaymentMode
    class _PaymentMode(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PaymentModeEnum.PaymentModeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(PaymentModeEnum.PaymentModeValue, 0)
        UNKNOWN = typing___cast(PaymentModeEnum.PaymentModeValue, 1)
        CLICKS = typing___cast(PaymentModeEnum.PaymentModeValue, 4)
        CONVERSION_VALUE = typing___cast(PaymentModeEnum.PaymentModeValue, 5)
        CONVERSIONS = typing___cast(PaymentModeEnum.PaymentModeValue, 6)
        GUEST_STAY = typing___cast(PaymentModeEnum.PaymentModeValue, 7)
    UNSPECIFIED = typing___cast(PaymentModeEnum.PaymentModeValue, 0)
    UNKNOWN = typing___cast(PaymentModeEnum.PaymentModeValue, 1)
    CLICKS = typing___cast(PaymentModeEnum.PaymentModeValue, 4)
    CONVERSION_VALUE = typing___cast(PaymentModeEnum.PaymentModeValue, 5)
    CONVERSIONS = typing___cast(PaymentModeEnum.PaymentModeValue, 6)
    GUEST_STAY = typing___cast(PaymentModeEnum.PaymentModeValue, 7)
    type___PaymentMode = PaymentMode
    def __init__(self,) -> None: ...

type___PaymentModeEnum = PaymentModeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudgetStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccountBudgetStatusValue = typing___NewType(
        "AccountBudgetStatusValue", builtin___int
    )
    type___AccountBudgetStatusValue = AccountBudgetStatusValue
    AccountBudgetStatus: _AccountBudgetStatus
    class _AccountBudgetStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccountBudgetStatusEnum.AccountBudgetStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 0)
        UNKNOWN = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 1)
        PENDING = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 2)
        APPROVED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 3)
        CANCELLED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 4)
    UNSPECIFIED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 0)
    UNKNOWN = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 1)
    PENDING = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 2)
    APPROVED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 3)
    CANCELLED = typing___cast(AccountBudgetStatusEnum.AccountBudgetStatusValue, 4)
    type___AccountBudgetStatus = AccountBudgetStatus
    def __init__(self,) -> None: ...

type___AccountBudgetStatusEnum = AccountBudgetStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.age_range_type_pb2 import (
    AgeRangeTypeEnum as google___ads___googleads___v4___enums___age_range_type_pb2___AgeRangeTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.app_payment_model_type_pb2 import (
    AppPaymentModelTypeEnum as google___ads___googleads___v4___enums___app_payment_model_type_pb2___AppPaymentModelTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.content_label_type_pb2 import (
    ContentLabelTypeEnum as google___ads___googleads___v4___enums___content_label_type_pb2___ContentLabelTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.day_of_week_pb2 import (
    DayOfWeekEnum as google___ads___googleads___v4___enums___day_of_week_pb2___DayOfWeekEnum,
)
from google.ads.google_ads.v4.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v4___enums___device_pb2___DeviceEnum,
)
from google.ads.google_ads.v4.proto.enums.gender_type_pb2 import (
    GenderTypeEnum as google___ads___googleads___v4___enums___gender_type_pb2___GenderTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.hotel_date_selection_type_pb2 import (
    HotelDateSelectionTypeEnum as google___ads___googleads___v4___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.income_range_type_pb2 import (
    IncomeRangeTypeEnum as google___ads___googleads___v4___enums___income_range_type_pb2___IncomeRangeTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.interaction_type_pb2 import (
    InteractionTypeEnum as google___ads___googleads___v4___enums___interaction_type_pb2___InteractionTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v4___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.listing_group_type_pb2 import (
    ListingGroupTypeEnum as google___ads___googleads___v4___enums___listing_group_type_pb2___ListingGroupTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.location_group_radius_units_pb2 import (
    LocationGroupRadiusUnitsEnum as google___ads___googleads___v4___enums___location_group_radius_units_pb2___LocationGroupRadiusUnitsEnum,
)
from google.ads.google_ads.v4.proto.enums.minute_of_hour_pb2 import (
    MinuteOfHourEnum as google___ads___googleads___v4___enums___minute_of_hour_pb2___MinuteOfHourEnum,
)
from google.ads.google_ads.v4.proto.enums.parental_status_type_pb2 import (
    ParentalStatusTypeEnum as google___ads___googleads___v4___enums___parental_status_type_pb2___ParentalStatusTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.preferred_content_type_pb2 import (
    PreferredContentTypeEnum as google___ads___googleads___v4___enums___preferred_content_type_pb2___PreferredContentTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.product_bidding_category_level_pb2 import (
    ProductBiddingCategoryLevelEnum as google___ads___googleads___v4___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum,
)
from google.ads.google_ads.v4.proto.enums.product_channel_exclusivity_pb2 import (
    ProductChannelExclusivityEnum as google___ads___googleads___v4___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum,
)
from google.ads.google_ads.v4.proto.enums.product_channel_pb2 import (
    ProductChannelEnum as google___ads___googleads___v4___enums___product_channel_pb2___ProductChannelEnum,
)
from google.ads.google_ads.v4.proto.enums.product_condition_pb2 import (
    ProductConditionEnum as google___ads___googleads___v4___enums___product_condition_pb2___ProductConditionEnum,
)
from google.ads.google_ads.v4.proto.enums.product_custom_attribute_index_pb2 import (
    ProductCustomAttributeIndexEnum as google___ads___googleads___v4___enums___product_custom_attribute_index_pb2___ProductCustomAttributeIndexEnum,
)
from google.ads.google_ads.v4.proto.enums.product_type_level_pb2 import (
    ProductTypeLevelEnum as google___ads___googleads___v4___enums___product_type_level_pb2___ProductTypeLevelEnum,
)
from google.ads.google_ads.v4.proto.enums.proximity_radius_units_pb2 import (
    ProximityRadiusUnitsEnum as google___ads___googleads___v4___enums___proximity_radius_units_pb2___ProximityRadiusUnitsEnum,
)
from google.ads.google_ads.v4.proto.enums.webpage_condition_operand_pb2 import (
    WebpageConditionOperandEnum as google___ads___googleads___v4___enums___webpage_condition_operand_pb2___WebpageConditionOperandEnum,
)
from google.ads.google_ads.v4.proto.enums.webpage_condition_operator_pb2 import (
    WebpageConditionOperatorEnum as google___ads___googleads___v4___enums___webpage_condition_operator_pb2___WebpageConditionOperatorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    match_type: google___ads___googleads___v4___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue = ...
    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        text: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        match_type: typing___Optional[
            google___ads___googleads___v4___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["text", b"text"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "match_type", b"match_type", "text", b"text"
        ],
    ) -> None: ...

type___KeywordInfo = KeywordInfo

class PlacementInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        url: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["url", b"url"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["url", b"url"]
    ) -> None: ...

type___PlacementInfo = PlacementInfo

class MobileAppCategoryInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def mobile_app_category_constant(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        mobile_app_category_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "mobile_app_category_constant", b"mobile_app_category_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mobile_app_category_constant", b"mobile_app_category_constant"
        ],
    ) -> None: ...

type___MobileAppCategoryInfo = MobileAppCategoryInfo

class MobileApplicationInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        app_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["app_id", b"app_id", "name", b"name"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["app_id", b"app_id", "name", b"name"],
    ) -> None: ...

type___MobileApplicationInfo = MobileApplicationInfo

class LocationInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def geo_target_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        geo_target_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant", b"geo_target_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant", b"geo_target_constant"
        ],
    ) -> None: ...

type___LocationInfo = LocationInfo

class DeviceInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___device_pb2___DeviceEnum.DeviceValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___device_pb2___DeviceEnum.DeviceValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___DeviceInfo = DeviceInfo

class PreferredContentInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___preferred_content_type_pb2___PreferredContentTypeEnum.PreferredContentTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___preferred_content_type_pb2___PreferredContentTypeEnum.PreferredContentTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___PreferredContentInfo = PreferredContentInfo

class ListingGroupInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___listing_group_type_pb2___ListingGroupTypeEnum.ListingGroupTypeValue = ...
    @property
    def case_value(self) -> type___ListingDimensionInfo: ...
    @property
    def parent_ad_group_criterion(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___listing_group_type_pb2___ListingGroupTypeEnum.ListingGroupTypeValue
        ] = None,
        case_value: typing___Optional[type___ListingDimensionInfo] = None,
        parent_ad_group_criterion: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "case_value",
            b"case_value",
            "parent_ad_group_criterion",
            b"parent_ad_group_criterion",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "case_value",
            b"case_value",
            "parent_ad_group_criterion",
            b"parent_ad_group_criterion",
            "type",
            b"type",
        ],
    ) -> None: ...

type___ListingGroupInfo = ListingGroupInfo

class ListingScopeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def dimensions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ListingDimensionInfo
    ]: ...
    def __init__(
        self,
        *,
        dimensions: typing___Optional[
            typing___Iterable[type___ListingDimensionInfo]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["dimensions", b"dimensions"]
    ) -> None: ...

type___ListingScopeInfo = ListingScopeInfo

class ListingDimensionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def hotel_id(self) -> type___HotelIdInfo: ...
    @property
    def hotel_class(self) -> type___HotelClassInfo: ...
    @property
    def hotel_country_region(self) -> type___HotelCountryRegionInfo: ...
    @property
    def hotel_state(self) -> type___HotelStateInfo: ...
    @property
    def hotel_city(self) -> type___HotelCityInfo: ...
    @property
    def product_bidding_category(self) -> type___ProductBiddingCategoryInfo: ...
    @property
    def product_brand(self) -> type___ProductBrandInfo: ...
    @property
    def product_channel(self) -> type___ProductChannelInfo: ...
    @property
    def product_channel_exclusivity(self) -> type___ProductChannelExclusivityInfo: ...
    @property
    def product_condition(self) -> type___ProductConditionInfo: ...
    @property
    def product_custom_attribute(self) -> type___ProductCustomAttributeInfo: ...
    @property
    def product_item_id(self) -> type___ProductItemIdInfo: ...
    @property
    def product_type(self) -> type___ProductTypeInfo: ...
    @property
    def unknown_listing_dimension(self) -> type___UnknownListingDimensionInfo: ...
    def __init__(
        self,
        *,
        hotel_id: typing___Optional[type___HotelIdInfo] = None,
        hotel_class: typing___Optional[type___HotelClassInfo] = None,
        hotel_country_region: typing___Optional[type___HotelCountryRegionInfo] = None,
        hotel_state: typing___Optional[type___HotelStateInfo] = None,
        hotel_city: typing___Optional[type___HotelCityInfo] = None,
        product_bidding_category: typing___Optional[
            type___ProductBiddingCategoryInfo
        ] = None,
        product_brand: typing___Optional[type___ProductBrandInfo] = None,
        product_channel: typing___Optional[type___ProductChannelInfo] = None,
        product_channel_exclusivity: typing___Optional[
            type___ProductChannelExclusivityInfo
        ] = None,
        product_condition: typing___Optional[type___ProductConditionInfo] = None,
        product_custom_attribute: typing___Optional[
            type___ProductCustomAttributeInfo
        ] = None,
        product_item_id: typing___Optional[type___ProductItemIdInfo] = None,
        product_type: typing___Optional[type___ProductTypeInfo] = None,
        unknown_listing_dimension: typing___Optional[
            type___UnknownListingDimensionInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "dimension",
            b"dimension",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country_region",
            b"hotel_country_region",
            "hotel_id",
            b"hotel_id",
            "hotel_state",
            b"hotel_state",
            "product_bidding_category",
            b"product_bidding_category",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_custom_attribute",
            b"product_custom_attribute",
            "product_item_id",
            b"product_item_id",
            "product_type",
            b"product_type",
            "unknown_listing_dimension",
            b"unknown_listing_dimension",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "dimension",
            b"dimension",
            "hotel_city",
            b"hotel_city",
            "hotel_class",
            b"hotel_class",
            "hotel_country_region",
            b"hotel_country_region",
            "hotel_id",
            b"hotel_id",
            "hotel_state",
            b"hotel_state",
            "product_bidding_category",
            b"product_bidding_category",
            "product_brand",
            b"product_brand",
            "product_channel",
            b"product_channel",
            "product_channel_exclusivity",
            b"product_channel_exclusivity",
            "product_condition",
            b"product_condition",
            "product_custom_attribute",
            b"product_custom_attribute",
            "product_item_id",
            b"product_item_id",
            "product_type",
            b"product_type",
            "unknown_listing_dimension",
            b"unknown_listing_dimension",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["dimension", b"dimension"]
    ) -> typing_extensions___Literal[
        "hotel_id",
        "hotel_class",
        "hotel_country_region",
        "hotel_state",
        "hotel_city",
        "product_bidding_category",
        "product_brand",
        "product_channel",
        "product_channel_exclusivity",
        "product_condition",
        "product_custom_attribute",
        "product_item_id",
        "product_type",
        "unknown_listing_dimension",
    ]: ...

type___ListingDimensionInfo = ListingDimensionInfo

class HotelIdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        value: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> None: ...

type___HotelIdInfo = HotelIdInfo

class HotelClassInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        value: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> None: ...

type___HotelClassInfo = HotelClassInfo

class HotelCountryRegionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def country_region_criterion(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        country_region_criterion: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "country_region_criterion", b"country_region_criterion"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "country_region_criterion", b"country_region_criterion"
        ],
    ) -> None: ...

type___HotelCountryRegionInfo = HotelCountryRegionInfo

class HotelStateInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def state_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        state_criterion: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["state_criterion", b"state_criterion"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["state_criterion", b"state_criterion"],
    ) -> None: ...

type___HotelStateInfo = HotelStateInfo

class HotelCityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def city_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        city_criterion: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["city_criterion", b"city_criterion"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["city_criterion", b"city_criterion"],
    ) -> None: ...

type___HotelCityInfo = HotelCityInfo

class ProductBiddingCategoryInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level: google___ads___googleads___v4___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        level: typing___Optional[
            google___ads___googleads___v4___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevelValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "country_code", b"country_code", "id", b"id"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "country_code", b"country_code", "id", b"id", "level", b"level"
        ],
    ) -> None: ...

type___ProductBiddingCategoryInfo = ProductBiddingCategoryInfo

class ProductBrandInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        value: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> None: ...

type___ProductBrandInfo = ProductBrandInfo

class ProductChannelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    channel: google___ads___googleads___v4___enums___product_channel_pb2___ProductChannelEnum.ProductChannelValue = ...
    def __init__(
        self,
        *,
        channel: typing___Optional[
            google___ads___googleads___v4___enums___product_channel_pb2___ProductChannelEnum.ProductChannelValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["channel", b"channel"]
    ) -> None: ...

type___ProductChannelInfo = ProductChannelInfo

class ProductChannelExclusivityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    channel_exclusivity: google___ads___googleads___v4___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivityValue = ...
    def __init__(
        self,
        *,
        channel_exclusivity: typing___Optional[
            google___ads___googleads___v4___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivityValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "channel_exclusivity", b"channel_exclusivity"
        ],
    ) -> None: ...

type___ProductChannelExclusivityInfo = ProductChannelExclusivityInfo

class ProductConditionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    condition: google___ads___googleads___v4___enums___product_condition_pb2___ProductConditionEnum.ProductConditionValue = ...
    def __init__(
        self,
        *,
        condition: typing___Optional[
            google___ads___googleads___v4___enums___product_condition_pb2___ProductConditionEnum.ProductConditionValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["condition", b"condition"]
    ) -> None: ...

type___ProductConditionInfo = ProductConditionInfo

class ProductCustomAttributeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    index: google___ads___googleads___v4___enums___product_custom_attribute_index_pb2___ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue = ...
    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        value: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        index: typing___Optional[
            google___ads___googleads___v4___enums___product_custom_attribute_index_pb2___ProductCustomAttributeIndexEnum.ProductCustomAttributeIndexValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["index", b"index", "value", b"value"],
    ) -> None: ...

type___ProductCustomAttributeInfo = ProductCustomAttributeInfo

class ProductItemIdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        value: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> None: ...

type___ProductItemIdInfo = ProductItemIdInfo

class ProductTypeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level: google___ads___googleads___v4___enums___product_type_level_pb2___ProductTypeLevelEnum.ProductTypeLevelValue = ...
    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        value: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        level: typing___Optional[
            google___ads___googleads___v4___enums___product_type_level_pb2___ProductTypeLevelEnum.ProductTypeLevelValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["level", b"level", "value", b"value"],
    ) -> None: ...

type___ProductTypeInfo = ProductTypeInfo

class UnknownListingDimensionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___UnknownListingDimensionInfo = UnknownListingDimensionInfo

class HotelDateSelectionTypeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___HotelDateSelectionTypeInfo = HotelDateSelectionTypeInfo

class HotelAdvanceBookingWindowInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def min_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def max_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        min_days: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        max_days: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "max_days", b"max_days", "min_days", b"min_days"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "max_days", b"max_days", "min_days", b"min_days"
        ],
    ) -> None: ...

type___HotelAdvanceBookingWindowInfo = HotelAdvanceBookingWindowInfo

class HotelLengthOfStayInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def min_nights(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def max_nights(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        min_nights: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        max_nights: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "max_nights", b"max_nights", "min_nights", b"min_nights"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "max_nights", b"max_nights", "min_nights", b"min_nights"
        ],
    ) -> None: ...

type___HotelLengthOfStayInfo = HotelLengthOfStayInfo

class HotelCheckInDayInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    day_of_week: google___ads___googleads___v4___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue = ...
    def __init__(
        self,
        *,
        day_of_week: typing___Optional[
            google___ads___googleads___v4___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["day_of_week", b"day_of_week"]
    ) -> None: ...

type___HotelCheckInDayInfo = HotelCheckInDayInfo

class InteractionTypeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___interaction_type_pb2___InteractionTypeEnum.InteractionTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___interaction_type_pb2___InteractionTypeEnum.InteractionTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___InteractionTypeInfo = InteractionTypeInfo

class AdScheduleInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_minute: google___ads___googleads___v4___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHourValue = ...
    end_minute: google___ads___googleads___v4___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHourValue = ...
    day_of_week: google___ads___googleads___v4___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue = ...
    @property
    def start_hour(self) -> google___protobuf___wrappers_pb2___Int32Value: ...
    @property
    def end_hour(self) -> google___protobuf___wrappers_pb2___Int32Value: ...
    def __init__(
        self,
        *,
        start_minute: typing___Optional[
            google___ads___googleads___v4___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHourValue
        ] = None,
        end_minute: typing___Optional[
            google___ads___googleads___v4___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHourValue
        ] = None,
        start_hour: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
        end_hour: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
        day_of_week: typing___Optional[
            google___ads___googleads___v4___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeekValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "end_hour", b"end_hour", "start_hour", b"start_hour"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "day_of_week",
            b"day_of_week",
            "end_hour",
            b"end_hour",
            "end_minute",
            b"end_minute",
            "start_hour",
            b"start_hour",
            "start_minute",
            b"start_minute",
        ],
    ) -> None: ...

type___AdScheduleInfo = AdScheduleInfo

class AgeRangeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___age_range_type_pb2___AgeRangeTypeEnum.AgeRangeTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___age_range_type_pb2___AgeRangeTypeEnum.AgeRangeTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___AgeRangeInfo = AgeRangeInfo

class GenderInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___gender_type_pb2___GenderTypeEnum.GenderTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___gender_type_pb2___GenderTypeEnum.GenderTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___GenderInfo = GenderInfo

class IncomeRangeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___income_range_type_pb2___IncomeRangeTypeEnum.IncomeRangeTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___income_range_type_pb2___IncomeRangeTypeEnum.IncomeRangeTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___IncomeRangeInfo = IncomeRangeInfo

class ParentalStatusInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___parental_status_type_pb2___ParentalStatusTypeEnum.ParentalStatusTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___parental_status_type_pb2___ParentalStatusTypeEnum.ParentalStatusTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___ParentalStatusInfo = ParentalStatusInfo

class YouTubeVideoInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        video_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["video_id", b"video_id"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["video_id", b"video_id"]
    ) -> None: ...

type___YouTubeVideoInfo = YouTubeVideoInfo

class YouTubeChannelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def channel_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        channel_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["channel_id", b"channel_id"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["channel_id", b"channel_id"]
    ) -> None: ...

type___YouTubeChannelInfo = YouTubeChannelInfo

class UserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def user_list(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        user_list: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["user_list", b"user_list"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["user_list", b"user_list"]
    ) -> None: ...

type___UserListInfo = UserListInfo

class ProximityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    radius_units: google___ads___googleads___v4___enums___proximity_radius_units_pb2___ProximityRadiusUnitsEnum.ProximityRadiusUnitsValue = ...
    @property
    def geo_point(self) -> type___GeoPointInfo: ...
    @property
    def radius(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def address(self) -> type___AddressInfo: ...
    def __init__(
        self,
        *,
        geo_point: typing___Optional[type___GeoPointInfo] = None,
        radius: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        radius_units: typing___Optional[
            google___ads___googleads___v4___enums___proximity_radius_units_pb2___ProximityRadiusUnitsEnum.ProximityRadiusUnitsValue
        ] = None,
        address: typing___Optional[type___AddressInfo] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "address", b"address", "geo_point", b"geo_point", "radius", b"radius"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "address",
            b"address",
            "geo_point",
            b"geo_point",
            "radius",
            b"radius",
            "radius_units",
            b"radius_units",
        ],
    ) -> None: ...

type___ProximityInfo = ProximityInfo

class GeoPointInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def longitude_in_micro_degrees(
        self,
    ) -> google___protobuf___wrappers_pb2___Int32Value: ...
    @property
    def latitude_in_micro_degrees(
        self,
    ) -> google___protobuf___wrappers_pb2___Int32Value: ...
    def __init__(
        self,
        *,
        longitude_in_micro_degrees: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
        latitude_in_micro_degrees: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "latitude_in_micro_degrees",
            b"latitude_in_micro_degrees",
            "longitude_in_micro_degrees",
            b"longitude_in_micro_degrees",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "latitude_in_micro_degrees",
            b"latitude_in_micro_degrees",
            "longitude_in_micro_degrees",
            b"longitude_in_micro_degrees",
        ],
    ) -> None: ...

type___GeoPointInfo = GeoPointInfo

class AddressInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def province_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def province_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def street_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def street_address2(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def city_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        postal_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        province_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        province_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        street_address: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        street_address2: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        city_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "city_name",
            b"city_name",
            "country_code",
            b"country_code",
            "postal_code",
            b"postal_code",
            "province_code",
            b"province_code",
            "province_name",
            b"province_name",
            "street_address",
            b"street_address",
            "street_address2",
            b"street_address2",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "city_name",
            b"city_name",
            "country_code",
            b"country_code",
            "postal_code",
            b"postal_code",
            "province_code",
            b"province_code",
            "province_name",
            b"province_name",
            "street_address",
            b"street_address",
            "street_address2",
            b"street_address2",
        ],
    ) -> None: ...

type___AddressInfo = AddressInfo

class TopicInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def topic_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def path(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    def __init__(
        self,
        *,
        topic_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        path: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["topic_constant", b"topic_constant"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "path", b"path", "topic_constant", b"topic_constant"
        ],
    ) -> None: ...

type___TopicInfo = TopicInfo

class LanguageInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def language_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        language_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "language_constant", b"language_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "language_constant", b"language_constant"
        ],
    ) -> None: ...

type___LanguageInfo = LanguageInfo

class IpBlockInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def ip_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        ip_address: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["ip_address", b"ip_address"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["ip_address", b"ip_address"]
    ) -> None: ...

type___IpBlockInfo = IpBlockInfo

class ContentLabelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___content_label_type_pb2___ContentLabelTypeEnum.ContentLabelTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___content_label_type_pb2___ContentLabelTypeEnum.ContentLabelTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___ContentLabelInfo = ContentLabelInfo

class CarrierInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def carrier_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        carrier_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "carrier_constant", b"carrier_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "carrier_constant", b"carrier_constant"
        ],
    ) -> None: ...

type___CarrierInfo = CarrierInfo

class UserInterestInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def user_interest_category(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        user_interest_category: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "user_interest_category", b"user_interest_category"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "user_interest_category", b"user_interest_category"
        ],
    ) -> None: ...

type___UserInterestInfo = UserInterestInfo

class WebpageInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def criterion_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def conditions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___WebpageConditionInfo
    ]: ...
    def __init__(
        self,
        *,
        criterion_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        conditions: typing___Optional[
            typing___Iterable[type___WebpageConditionInfo]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["criterion_name", b"criterion_name"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "conditions", b"conditions", "criterion_name", b"criterion_name"
        ],
    ) -> None: ...

type___WebpageInfo = WebpageInfo

class WebpageConditionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operand: google___ads___googleads___v4___enums___webpage_condition_operand_pb2___WebpageConditionOperandEnum.WebpageConditionOperandValue = ...
    operator: google___ads___googleads___v4___enums___webpage_condition_operator_pb2___WebpageConditionOperatorEnum.WebpageConditionOperatorValue = ...
    @property
    def argument(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        operand: typing___Optional[
            google___ads___googleads___v4___enums___webpage_condition_operand_pb2___WebpageConditionOperandEnum.WebpageConditionOperandValue
        ] = None,
        operator: typing___Optional[
            google___ads___googleads___v4___enums___webpage_condition_operator_pb2___WebpageConditionOperatorEnum.WebpageConditionOperatorValue
        ] = None,
        argument: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["argument", b"argument"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "argument", b"argument", "operand", b"operand", "operator", b"operator"
        ],
    ) -> None: ...

type___WebpageConditionInfo = WebpageConditionInfo

class OperatingSystemVersionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def operating_system_version_constant(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        operating_system_version_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "operating_system_version_constant", b"operating_system_version_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "operating_system_version_constant", b"operating_system_version_constant"
        ],
    ) -> None: ...

type___OperatingSystemVersionInfo = OperatingSystemVersionInfo

class AppPaymentModelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___app_payment_model_type_pb2___AppPaymentModelTypeEnum.AppPaymentModelTypeValue = ...
    def __init__(
        self,
        *,
        type: typing___Optional[
            google___ads___googleads___v4___enums___app_payment_model_type_pb2___AppPaymentModelTypeEnum.AppPaymentModelTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["type", b"type"]
    ) -> None: ...

type___AppPaymentModelInfo = AppPaymentModelInfo

class MobileDeviceInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def mobile_device_constant(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        mobile_device_constant: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "mobile_device_constant", b"mobile_device_constant"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mobile_device_constant", b"mobile_device_constant"
        ],
    ) -> None: ...

type___MobileDeviceInfo = MobileDeviceInfo

class CustomAffinityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def custom_affinity(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        custom_affinity: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["custom_affinity", b"custom_affinity"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["custom_affinity", b"custom_affinity"],
    ) -> None: ...

type___CustomAffinityInfo = CustomAffinityInfo

class CustomIntentInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def custom_intent(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        custom_intent: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["custom_intent", b"custom_intent"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["custom_intent", b"custom_intent"]
    ) -> None: ...

type___CustomIntentInfo = CustomIntentInfo

class LocationGroupInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    radius_units: google___ads___googleads___v4___enums___location_group_radius_units_pb2___LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnitsValue = ...
    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def geo_target_constants(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def radius(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        feed: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_constants: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        radius: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        radius_units: typing___Optional[
            google___ads___googleads___v4___enums___location_group_radius_units_pb2___LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnitsValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["feed", b"feed", "radius", b"radius"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "feed",
            b"feed",
            "geo_target_constants",
            b"geo_target_constants",
            "radius",
            b"radius",
            "radius_units",
            b"radius_units",
        ],
    ) -> None: ...

type___LocationGroupInfo = LocationGroupInfo



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTargetStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemTargetStatusValue = typing___NewType(
        "FeedItemTargetStatusValue", builtin___int
    )
    type___FeedItemTargetStatusValue = FeedItemTargetStatusValue
    FeedItemTargetStatus: _FeedItemTargetStatus
    class _FeedItemTargetStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemTargetStatusEnum.FeedItemTargetStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 0
        )
        UNKNOWN = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 1)
        ENABLED = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 2)
        REMOVED = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 3)
    UNSPECIFIED = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 0)
    UNKNOWN = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 1)
    ENABLED = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 2)
    REMOVED = typing___cast(FeedItemTargetStatusEnum.FeedItemTargetStatusValue, 3)
    type___FeedItemTargetStatus = FeedItemTargetStatus
    def __init__(self,) -> None: ...

type___FeedItemTargetStatusEnum = FeedItemTargetStatusEnum



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['google-stubs',
 'google-stubs.ads.google_ads.interceptors',
 'google-stubs.ads.google_ads.v5.proto.enums']

package_data = \
{'': ['*'],
 'google-stubs': ['ads/*',
                  'ads/google_ads/*',
                  'ads/google_ads/v3/*',
                  'ads/google_ads/v3/proto/*',
                  'ads/google_ads/v3/proto/common/*',
                  'ads/google_ads/v3/proto/enums/*',
                  'ads/google_ads/v3/proto/errors/*',
                  'ads/google_ads/v3/proto/resources/*',
                  'ads/google_ads/v3/proto/services/*',
                  'ads/google_ads/v3/services/*',
                  'ads/google_ads/v3/services/transports/*',
                  'ads/google_ads/v4/*',
                  'ads/google_ads/v4/proto/*',
                  'ads/google_ads/v4/proto/common/*',
                  'ads/google_ads/v4/proto/enums/*',
                  'ads/google_ads/v4/proto/errors/*',
                  'ads/google_ads/v4/proto/resources/*',
                  'ads/google_ads/v4/proto/services/*',
                  'ads/google_ads/v4/services/*',
                  'ads/google_ads/v4/services/transports/*',
                  'ads/google_ads/v5/*',
                  'ads/google_ads/v5/proto/*',
                  'ads/google_ads/v5/proto/common/*',
                  'ads/google_ads/v5/proto/errors/*',
                  'ads/google_ads/v5/proto/resources/*',
                  'ads/google_ads/v5/proto/services/*',
                  'ads/google_ads/v5/services/*',
                  'ads/google_ads/v5/services/transports/*',
                  'ads/google_ads/v6/*',
                  'ads/google_ads/v6/proto/*',
                  'ads/google_ads/v6/proto/common/*',
                  'ads/google_ads/v6/proto/enums/*',
                  'ads/google_ads/v6/proto/errors/*',
                  'ads/google_ads/v6/proto/resources/*',
                  'ads/google_ads/v6/proto/services/*',
                  'ads/google_ads/v6/services/*',
                  'ads/google_ads/v6/services/transports/*']}

install_requires = \
['google-ads>=8.0.0,<9.0.0',
 'googleapis-common-protos-stubs>=1.0,<2.0',
 'typing-extensions>=3.7,<4.0']

setup_kwargs = {
    'name': 'google-ads-stubs',
    'version': '5.0.1',
    'description': 'Type stubs for google-ads',
    'long_description': "# Type stubs for the Google Ads API Client Library for Python\n\n[![PyPI version](https://badge.fury.io/py/google-ads-stubs.svg)](https://badge.fury.io/py/google-ads-stubs)\n\nThis package provides type stubs for the [Google Ads API Client Library for Python](https://github.com/googleads/google-ads-python). \nIt's currently compatible with v.8.0.0 of this library. It allows you to type check usage of the library with e.g. [mypy](http://mypy-lang.org/) and will also improve autocomplete in many editors.\n\n**This is in no way affiliated with Google.**\n\nThe stubs for protobuf messages were created by [mypy-protobuf](https://github.com/dropbox/mypy-protobuf).\nThe rest were created either by hand or by self-made scripts, with the output of MyPy's `stubgen` as\na starting point.\n\nIf you find incorrect annotations, please create an issue. Contributions for fixes are also welcome.\n\n## Installation\n\n```\n$ pip install google-ads-stubs\n```\n\n## Caveats\n\nThere are some caveats. The primary one is that type inference does _not_ work for the `get_type` and `get_service`\nmethods of `Client`. The workaround is to explicitly state the type. For `get_type` you can also instantiate\nthe object directly.\n\n```python\n# Replace this:\ncampaign_operation = client.get_type('CampaignOperation')\n# With this:\nfrom google.ads.google_ads.v3.types import CampaignOperation\ncampaign_operation: CampaignOperation = client.get_type('CampaignOperation')\n# Or this:\nfrom google.ads.google_ads.v3.types import CampaignOperation\ncampaign_operation = CampaignOperation()\n\n# Replace this:\ngoogle_ads_service = client.get_service('GoogleAdsService')\n# With this:\nfrom google.ads.google_ads.v3.services import GoogleAdsServiceClient\ngoogle_ads_service: GoogleAdsServiceClient = client.get_service('GoogleAdsService')\n```\n\nWhile it is technically possible to type these methods using a combination of overloading and literal types,\nthis is not included in these stubs. The reason is that it requires about 10,000 overloads, which, while simple\nto generate, slows type checking to a crawl.\n\nThis package does not provide complete type annotations, although it should cover what's used by most developers.\nThe bare output from `stubgen` is used by the service stubs and transport classes.\nThe service stubs are unlikely to be typed as long as there is no `mypy-protobuf` equivalent\nfor GRPC stubs. The transport classes may be typed in the future if there is a need for it.\n\nSome service methods allow you to pass in either a protobuf message or a dictionary for certain arguments.\nThere is no check that the dictionary conforms to the message structure, as this would require a `TypedDict` subclass\nfor each message.\n",
    'author': 'Henrik Bruåsdal',
    'author_email': 'henrik.bruasdal@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/henribru/google-ads-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.response_content_type_pb2 import (
    ResponseContentTypeEnum as google___ads___googleads___v6___enums___response_content_type_pb2___ResponseContentTypeEnum,
)
from google.ads.google_ads.v6.proto.resources.feed_item_target_pb2 import (
    FeedItemTarget as google___ads___googleads___v6___resources___feed_item_target_pb2___FeedItemTarget,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetFeedItemTargetRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetFeedItemTargetRequest = GetFeedItemTargetRequest

class MutateFeedItemTargetsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    response_content_type: google___ads___googleads___v6___enums___response_content_type_pb2___ResponseContentTypeEnum.ResponseContentTypeValue = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___FeedItemTargetOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[type___FeedItemTargetOperation]
        ] = None,
        response_content_type: typing___Optional[
            google___ads___googleads___v6___enums___response_content_type_pb2___ResponseContentTypeEnum.ResponseContentTypeValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "response_content_type",
            b"response_content_type",
        ],
    ) -> None: ...

type___MutateFeedItemTargetsRequest = MutateFeedItemTargetsRequest

class FeedItemTargetOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove: typing___Text = ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v6___resources___feed_item_target_pb2___FeedItemTarget: ...
    def __init__(
        self,
        *,
        create: typing___Optional[
            google___ads___googleads___v6___resources___feed_item_target_pb2___FeedItemTarget
        ] = None,
        remove: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create", "remove"]: ...

type___FeedItemTargetOperation = FeedItemTargetOperation

class MutateFeedItemTargetsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateFeedItemTargetResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[
            typing___Iterable[type___MutateFeedItemTargetResult]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["results", b"results"]
    ) -> None: ...

type___MutateFeedItemTargetsResponse = MutateFeedItemTargetsResponse

class MutateFeedItemTargetResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def feed_item_target(
        self,
    ) -> google___ads___googleads___v6___resources___feed_item_target_pb2___FeedItemTarget: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed_item_target: typing___Optional[
            google___ads___googleads___v6___resources___feed_item_target_pb2___FeedItemTarget
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "feed_item_target", b"feed_item_target"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "feed_item_target", b"feed_item_target", "resource_name", b"resource_name"
        ],
    ) -> None: ...

type___MutateFeedItemTargetResult = MutateFeedItemTargetResult



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AdTypeValue = typing___NewType("AdTypeValue", builtin___int)
    type___AdTypeValue = AdTypeValue
    AdType: _AdType
    class _AdType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AdTypeEnum.AdTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AdTypeEnum.AdTypeValue, 0)
        UNKNOWN = typing___cast(AdTypeEnum.AdTypeValue, 1)
        TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 2)
        EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 3)
        CALL_ONLY_AD = typing___cast(AdTypeEnum.AdTypeValue, 6)
        EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 7)
        HOTEL_AD = typing___cast(AdTypeEnum.AdTypeValue, 8)
        SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdTypeValue, 9)
        SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdTypeValue, 10)
        VIDEO_AD = typing___cast(AdTypeEnum.AdTypeValue, 12)
        GMAIL_AD = typing___cast(AdTypeEnum.AdTypeValue, 13)
        IMAGE_AD = typing___cast(AdTypeEnum.AdTypeValue, 14)
        RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 15)
        LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 16)
        APP_AD = typing___cast(AdTypeEnum.AdTypeValue, 17)
        LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdTypeValue, 18)
        RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 19)
        LOCAL_AD = typing___cast(AdTypeEnum.AdTypeValue, 20)
        HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdTypeValue, 21)
        DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdTypeValue, 22)
        APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdTypeValue, 23)
        SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdTypeValue, 24)
        VIDEO_BUMPER_AD = typing___cast(AdTypeEnum.AdTypeValue, 25)
        VIDEO_NON_SKIPPABLE_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 26)
        VIDEO_OUTSTREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 27)
        VIDEO_TRUEVIEW_DISCOVERY_AD = typing___cast(AdTypeEnum.AdTypeValue, 28)
        VIDEO_TRUEVIEW_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 29)
        VIDEO_RESPONSIVE_AD = typing___cast(AdTypeEnum.AdTypeValue, 30)
    UNSPECIFIED = typing___cast(AdTypeEnum.AdTypeValue, 0)
    UNKNOWN = typing___cast(AdTypeEnum.AdTypeValue, 1)
    TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 2)
    EXPANDED_TEXT_AD = typing___cast(AdTypeEnum.AdTypeValue, 3)
    CALL_ONLY_AD = typing___cast(AdTypeEnum.AdTypeValue, 6)
    EXPANDED_DYNAMIC_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 7)
    HOTEL_AD = typing___cast(AdTypeEnum.AdTypeValue, 8)
    SHOPPING_SMART_AD = typing___cast(AdTypeEnum.AdTypeValue, 9)
    SHOPPING_PRODUCT_AD = typing___cast(AdTypeEnum.AdTypeValue, 10)
    VIDEO_AD = typing___cast(AdTypeEnum.AdTypeValue, 12)
    GMAIL_AD = typing___cast(AdTypeEnum.AdTypeValue, 13)
    IMAGE_AD = typing___cast(AdTypeEnum.AdTypeValue, 14)
    RESPONSIVE_SEARCH_AD = typing___cast(AdTypeEnum.AdTypeValue, 15)
    LEGACY_RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 16)
    APP_AD = typing___cast(AdTypeEnum.AdTypeValue, 17)
    LEGACY_APP_INSTALL_AD = typing___cast(AdTypeEnum.AdTypeValue, 18)
    RESPONSIVE_DISPLAY_AD = typing___cast(AdTypeEnum.AdTypeValue, 19)
    LOCAL_AD = typing___cast(AdTypeEnum.AdTypeValue, 20)
    HTML5_UPLOAD_AD = typing___cast(AdTypeEnum.AdTypeValue, 21)
    DYNAMIC_HTML5_AD = typing___cast(AdTypeEnum.AdTypeValue, 22)
    APP_ENGAGEMENT_AD = typing___cast(AdTypeEnum.AdTypeValue, 23)
    SHOPPING_COMPARISON_LISTING_AD = typing___cast(AdTypeEnum.AdTypeValue, 24)
    VIDEO_BUMPER_AD = typing___cast(AdTypeEnum.AdTypeValue, 25)
    VIDEO_NON_SKIPPABLE_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 26)
    VIDEO_OUTSTREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 27)
    VIDEO_TRUEVIEW_DISCOVERY_AD = typing___cast(AdTypeEnum.AdTypeValue, 28)
    VIDEO_TRUEVIEW_IN_STREAM_AD = typing___cast(AdTypeEnum.AdTypeValue, 29)
    VIDEO_RESPONSIVE_AD = typing___cast(AdTypeEnum.AdTypeValue, 30)
    type___AdType = AdType
    def __init__(self,) -> None: ...

type___AdTypeEnum = AdTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerClient(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    client_customer: typing___Text = ...
    hidden: builtin___bool = ...
    level: builtin___int = ...
    time_zone: typing___Text = ...
    test_account: builtin___bool = ...
    manager: builtin___bool = ...
    descriptive_name: typing___Text = ...
    currency_code: typing___Text = ...
    id: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        client_customer: typing___Optional[typing___Text] = None,
        hidden: typing___Optional[builtin___bool] = None,
        level: typing___Optional[builtin___int] = None,
        time_zone: typing___Optional[typing___Text] = None,
        test_account: typing___Optional[builtin___bool] = None,
        manager: typing___Optional[builtin___bool] = None,
        descriptive_name: typing___Optional[typing___Text] = None,
        currency_code: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_client_customer",
            b"_client_customer",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_hidden",
            b"_hidden",
            "_id",
            b"_id",
            "_level",
            b"_level",
            "_manager",
            b"_manager",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "client_customer",
            b"client_customer",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "hidden",
            b"hidden",
            "id",
            b"id",
            "level",
            b"level",
            "manager",
            b"manager",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_client_customer", b"_client_customer"
        ],
    ) -> typing_extensions___Literal["client_customer"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_descriptive_name", b"_descriptive_name"
        ],
    ) -> typing_extensions___Literal["descriptive_name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_hidden", b"_hidden"]
    ) -> typing_extensions___Literal["hidden"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_level", b"_level"]
    ) -> typing_extensions___Literal["level"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_manager", b"_manager"]
    ) -> typing_extensions___Literal["manager"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_test_account", b"_test_account"],
    ) -> typing_extensions___Literal["test_account"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_time_zone", b"_time_zone"]
    ) -> typing_extensions___Literal["time_zone"]: ...

type___CustomerClient = CustomerClient



from typing import Any

class PaidOrganicSearchTermViewServiceStub:
    GetPaidOrganicSearchTermView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class PaidOrganicSearchTermViewServiceServicer:
    def GetPaidOrganicSearchTermView(self, request: Any, context: Any) -> None: ...

def add_PaidOrganicSearchTermViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomAudienceMemberTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomAudienceMemberTypeValue = typing___NewType(
        "CustomAudienceMemberTypeValue", builtin___int
    )
    type___CustomAudienceMemberTypeValue = CustomAudienceMemberTypeValue
    CustomAudienceMemberType: _CustomAudienceMemberType
    class _CustomAudienceMemberType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 0
        )
        UNKNOWN = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 1
        )
        KEYWORD = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 2
        )
        URL = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 3
        )
        PLACE_CATEGORY = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 4
        )
        APP = typing___cast(
            CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 5
        )
    UNSPECIFIED = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 0
    )
    UNKNOWN = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 1
    )
    KEYWORD = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 2
    )
    URL = typing___cast(CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 3)
    PLACE_CATEGORY = typing___cast(
        CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 4
    )
    APP = typing___cast(CustomAudienceMemberTypeEnum.CustomAudienceMemberTypeValue, 5)
    type___CustomAudienceMemberType = CustomAudienceMemberType
    def __init__(self,) -> None: ...

type___CustomAudienceMemberTypeEnum = CustomAudienceMemberTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BiddingStrategyTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BiddingStrategyTypeValue = typing___NewType(
        "BiddingStrategyTypeValue", builtin___int
    )
    type___BiddingStrategyTypeValue = BiddingStrategyTypeValue
    BiddingStrategyType: _BiddingStrategyType
    class _BiddingStrategyType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 0)
        UNKNOWN = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 1)
        COMMISSION = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 16)
        ENHANCED_CPC = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 2
        )
        MANUAL_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 3)
        MANUAL_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 4)
        MANUAL_CPV = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 13)
        MAXIMIZE_CONVERSIONS = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 10
        )
        MAXIMIZE_CONVERSION_VALUE = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 11
        )
        PAGE_ONE_PROMOTED = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 5
        )
        PERCENT_CPC = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 12
        )
        TARGET_CPA = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 6)
        TARGET_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 14)
        TARGET_IMPRESSION_SHARE = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 15
        )
        TARGET_OUTRANK_SHARE = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 7
        )
        TARGET_ROAS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 8)
        TARGET_SPEND = typing___cast(
            BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 9
        )
    UNSPECIFIED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 0)
    UNKNOWN = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 1)
    COMMISSION = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 16)
    ENHANCED_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 2)
    MANUAL_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 3)
    MANUAL_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 4)
    MANUAL_CPV = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 13)
    MAXIMIZE_CONVERSIONS = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 10
    )
    MAXIMIZE_CONVERSION_VALUE = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 11
    )
    PAGE_ONE_PROMOTED = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 5
    )
    PERCENT_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 12)
    TARGET_CPA = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 6)
    TARGET_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 14)
    TARGET_IMPRESSION_SHARE = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 15
    )
    TARGET_OUTRANK_SHARE = typing___cast(
        BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 7
    )
    TARGET_ROAS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 8)
    TARGET_SPEND = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyTypeValue, 9)
    type___BiddingStrategyType = BiddingStrategyType
    def __init__(self,) -> None: ...

type___BiddingStrategyTypeEnum = BiddingStrategyTypeEnum



from typing import Any

class HotelPerformanceViewServiceStub:
    GetHotelPerformanceView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class HotelPerformanceViewServiceServicer:
    def GetHotelPerformanceView(self, request: Any, context: Any) -> None: ...

def add_HotelPerformanceViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AgeRangeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AgeRangeTypeValue = typing___NewType("AgeRangeTypeValue", builtin___int)
    type___AgeRangeTypeValue = AgeRangeTypeValue
    AgeRangeType: _AgeRangeType
    class _AgeRangeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AgeRangeTypeEnum.AgeRangeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 0)
        UNKNOWN = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 1)
        AGE_RANGE_18_24 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503001)
        AGE_RANGE_25_34 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503002)
        AGE_RANGE_35_44 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503003)
        AGE_RANGE_45_54 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503004)
        AGE_RANGE_55_64 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503005)
        AGE_RANGE_65_UP = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503006)
        AGE_RANGE_UNDETERMINED = typing___cast(
            AgeRangeTypeEnum.AgeRangeTypeValue, 503999
        )
    UNSPECIFIED = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 0)
    UNKNOWN = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 1)
    AGE_RANGE_18_24 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503001)
    AGE_RANGE_25_34 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503002)
    AGE_RANGE_35_44 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503003)
    AGE_RANGE_45_54 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503004)
    AGE_RANGE_55_64 = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503005)
    AGE_RANGE_65_UP = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503006)
    AGE_RANGE_UNDETERMINED = typing___cast(AgeRangeTypeEnum.AgeRangeTypeValue, 503999)
    type___AgeRangeType = AgeRangeType
    def __init__(self,) -> None: ...

type___AgeRangeTypeEnum = AgeRangeTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.field_mask_pb2 import (
    FieldMask as google___protobuf___field_mask_pb2___FieldMask,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.keyword_plan_common_pb2 import (
    KeywordPlanHistoricalMetrics as google___ads___googleads___v5___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics,
)
from google.ads.google_ads.v5.proto.resources.keyword_plan_pb2 import (
    KeywordPlan as google___ads___googleads___v5___resources___keyword_plan_pb2___KeywordPlan,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetKeywordPlanRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetKeywordPlanRequest = GetKeywordPlanRequest

class MutateKeywordPlansRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    validate_only: builtin___bool = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[type___KeywordPlanOperation]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
        validate_only: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

type___MutateKeywordPlansRequest = MutateKeywordPlansRequest

class KeywordPlanOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove: typing___Text = ...
    @property
    def update_mask(self) -> google___protobuf___field_mask_pb2___FieldMask: ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v5___resources___keyword_plan_pb2___KeywordPlan: ...
    @property
    def update(
        self,
    ) -> google___ads___googleads___v5___resources___keyword_plan_pb2___KeywordPlan: ...
    def __init__(
        self,
        *,
        update_mask: typing___Optional[
            google___protobuf___field_mask_pb2___FieldMask
        ] = None,
        create: typing___Optional[
            google___ads___googleads___v5___resources___keyword_plan_pb2___KeywordPlan
        ] = None,
        update: typing___Optional[
            google___ads___googleads___v5___resources___keyword_plan_pb2___KeywordPlan
        ] = None,
        remove: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create",
            b"create",
            "operation",
            b"operation",
            "remove",
            b"remove",
            "update",
            b"update",
            "update_mask",
            b"update_mask",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create", "update", "remove"]: ...

type___KeywordPlanOperation = KeywordPlanOperation

class MutateKeywordPlansResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MutateKeywordPlansResult
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
        results: typing___Optional[
            typing___Iterable[type___MutateKeywordPlansResult]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___MutateKeywordPlansResponse = MutateKeywordPlansResponse

class MutateKeywordPlansResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateKeywordPlansResult = MutateKeywordPlansResult

class GenerateForecastCurveRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan: typing___Text = ...
    def __init__(
        self, *, keyword_plan: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

type___GenerateForecastCurveRequest = GenerateForecastCurveRequest

class GenerateForecastCurveResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def campaign_forecast_curves(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanCampaignForecastCurve
    ]: ...
    def __init__(
        self,
        *,
        campaign_forecast_curves: typing___Optional[
            typing___Iterable[type___KeywordPlanCampaignForecastCurve]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_forecast_curves", b"campaign_forecast_curves"
        ],
    ) -> None: ...

type___GenerateForecastCurveResponse = GenerateForecastCurveResponse

class GenerateForecastTimeSeriesRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan: typing___Text = ...
    def __init__(
        self, *, keyword_plan: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

type___GenerateForecastTimeSeriesRequest = GenerateForecastTimeSeriesRequest

class GenerateForecastTimeSeriesResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def weekly_time_series_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanWeeklyTimeSeriesForecast
    ]: ...
    def __init__(
        self,
        *,
        weekly_time_series_forecasts: typing___Optional[
            typing___Iterable[type___KeywordPlanWeeklyTimeSeriesForecast]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "weekly_time_series_forecasts", b"weekly_time_series_forecasts"
        ],
    ) -> None: ...

type___GenerateForecastTimeSeriesResponse = GenerateForecastTimeSeriesResponse

class GenerateForecastMetricsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan: typing___Text = ...
    def __init__(
        self, *, keyword_plan: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

type___GenerateForecastMetricsRequest = GenerateForecastMetricsRequest

class GenerateForecastMetricsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def campaign_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanCampaignForecast
    ]: ...
    @property
    def ad_group_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanAdGroupForecast
    ]: ...
    @property
    def keyword_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanKeywordForecast
    ]: ...
    def __init__(
        self,
        *,
        campaign_forecasts: typing___Optional[
            typing___Iterable[type___KeywordPlanCampaignForecast]
        ] = None,
        ad_group_forecasts: typing___Optional[
            typing___Iterable[type___KeywordPlanAdGroupForecast]
        ] = None,
        keyword_forecasts: typing___Optional[
            typing___Iterable[type___KeywordPlanKeywordForecast]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_forecasts",
            b"ad_group_forecasts",
            "campaign_forecasts",
            b"campaign_forecasts",
            "keyword_forecasts",
            b"keyword_forecasts",
        ],
    ) -> None: ...

type___GenerateForecastMetricsResponse = GenerateForecastMetricsResponse

class KeywordPlanCampaignForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def keyword_plan_campaign(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign_forecast(self) -> type___ForecastMetrics: ...
    def __init__(
        self,
        *,
        keyword_plan_campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign_forecast: typing___Optional[type___ForecastMetrics] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_forecast",
            b"campaign_forecast",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "campaign_forecast",
            b"campaign_forecast",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
        ],
    ) -> None: ...

type___KeywordPlanCampaignForecast = KeywordPlanCampaignForecast

class KeywordPlanAdGroupForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def keyword_plan_ad_group(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group_forecast(self) -> type___ForecastMetrics: ...
    def __init__(
        self,
        *,
        keyword_plan_ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        ad_group_forecast: typing___Optional[type___ForecastMetrics] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_forecast",
            b"ad_group_forecast",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_forecast",
            b"ad_group_forecast",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
        ],
    ) -> None: ...

type___KeywordPlanAdGroupForecast = KeywordPlanAdGroupForecast

class KeywordPlanKeywordForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def keyword_plan_ad_group_keyword(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def keyword_forecast(self) -> type___ForecastMetrics: ...
    def __init__(
        self,
        *,
        keyword_plan_ad_group_keyword: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        keyword_forecast: typing___Optional[type___ForecastMetrics] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_forecast",
            b"keyword_forecast",
            "keyword_plan_ad_group_keyword",
            b"keyword_plan_ad_group_keyword",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_forecast",
            b"keyword_forecast",
            "keyword_plan_ad_group_keyword",
            b"keyword_plan_ad_group_keyword",
        ],
    ) -> None: ...

type___KeywordPlanKeywordForecast = KeywordPlanKeywordForecast

class KeywordPlanCampaignForecastCurve(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def keyword_plan_campaign(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def max_cpc_bid_forecast_curve(
        self,
    ) -> type___KeywordPlanMaxCpcBidForecastCurve: ...
    def __init__(
        self,
        *,
        keyword_plan_campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        max_cpc_bid_forecast_curve: typing___Optional[
            type___KeywordPlanMaxCpcBidForecastCurve
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "max_cpc_bid_forecast_curve",
            b"max_cpc_bid_forecast_curve",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "max_cpc_bid_forecast_curve",
            b"max_cpc_bid_forecast_curve",
        ],
    ) -> None: ...

type___KeywordPlanCampaignForecastCurve = KeywordPlanCampaignForecastCurve

class KeywordPlanMaxCpcBidForecastCurve(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def max_cpc_bid_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanMaxCpcBidForecast
    ]: ...
    def __init__(
        self,
        *,
        max_cpc_bid_forecasts: typing___Optional[
            typing___Iterable[type___KeywordPlanMaxCpcBidForecast]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "max_cpc_bid_forecasts", b"max_cpc_bid_forecasts"
        ],
    ) -> None: ...

type___KeywordPlanMaxCpcBidForecastCurve = KeywordPlanMaxCpcBidForecastCurve

class KeywordPlanMaxCpcBidForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def max_cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def max_cpc_bid_forecast(self) -> type___ForecastMetrics: ...
    def __init__(
        self,
        *,
        max_cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        max_cpc_bid_forecast: typing___Optional[type___ForecastMetrics] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "max_cpc_bid_forecast",
            b"max_cpc_bid_forecast",
            "max_cpc_bid_micros",
            b"max_cpc_bid_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "max_cpc_bid_forecast",
            b"max_cpc_bid_forecast",
            "max_cpc_bid_micros",
            b"max_cpc_bid_micros",
        ],
    ) -> None: ...

type___KeywordPlanMaxCpcBidForecast = KeywordPlanMaxCpcBidForecast

class KeywordPlanWeeklyTimeSeriesForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan_campaign: typing___Text = ...
    @property
    def weekly_forecasts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanWeeklyForecast
    ]: ...
    def __init__(
        self,
        *,
        keyword_plan_campaign: typing___Optional[typing___Text] = None,
        weekly_forecasts: typing___Optional[
            typing___Iterable[type___KeywordPlanWeeklyForecast]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_keyword_plan_campaign",
            b"_keyword_plan_campaign",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "weekly_forecasts",
            b"weekly_forecasts",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_keyword_plan_campaign", b"_keyword_plan_campaign"
        ],
    ) -> typing_extensions___Literal["keyword_plan_campaign"]: ...

type___KeywordPlanWeeklyTimeSeriesForecast = KeywordPlanWeeklyTimeSeriesForecast

class KeywordPlanWeeklyForecast(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_date: typing___Text = ...
    @property
    def forecast(self) -> type___ForecastMetrics: ...
    def __init__(
        self,
        *,
        start_date: typing___Optional[typing___Text] = None,
        forecast: typing___Optional[type___ForecastMetrics] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_start_date",
            b"_start_date",
            "forecast",
            b"forecast",
            "start_date",
            b"start_date",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_start_date",
            b"_start_date",
            "forecast",
            b"forecast",
            "start_date",
            b"start_date",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_start_date", b"_start_date"]
    ) -> typing_extensions___Literal["start_date"]: ...

type___KeywordPlanWeeklyForecast = KeywordPlanWeeklyForecast

class ForecastMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def ctr(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def average_cpc(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        impressions: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        ctr: typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        average_cpc: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        clicks: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "average_cpc",
            b"average_cpc",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "ctr",
            b"ctr",
            "impressions",
            b"impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "average_cpc",
            b"average_cpc",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "ctr",
            b"ctr",
            "impressions",
            b"impressions",
        ],
    ) -> None: ...

type___ForecastMetrics = ForecastMetrics

class GenerateHistoricalMetricsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    keyword_plan: typing___Text = ...
    def __init__(
        self, *, keyword_plan: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["keyword_plan", b"keyword_plan"]
    ) -> None: ...

type___GenerateHistoricalMetricsRequest = GenerateHistoricalMetricsRequest

class GenerateHistoricalMetricsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def metrics(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___KeywordPlanKeywordHistoricalMetrics
    ]: ...
    def __init__(
        self,
        *,
        metrics: typing___Optional[
            typing___Iterable[type___KeywordPlanKeywordHistoricalMetrics]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["metrics", b"metrics"]
    ) -> None: ...

type___GenerateHistoricalMetricsResponse = GenerateHistoricalMetricsResponse

class KeywordPlanKeywordHistoricalMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    close_variants: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    @property
    def search_query(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def keyword_metrics(
        self,
    ) -> google___ads___googleads___v5___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics: ...
    def __init__(
        self,
        *,
        search_query: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        close_variants: typing___Optional[typing___Iterable[typing___Text]] = None,
        keyword_metrics: typing___Optional[
            google___ads___googleads___v5___common___keyword_plan_common_pb2___KeywordPlanHistoricalMetrics
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "keyword_metrics", b"keyword_metrics", "search_query", b"search_query"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "close_variants",
            b"close_variants",
            "keyword_metrics",
            b"keyword_metrics",
            "search_query",
            b"search_query",
        ],
    ) -> None: ...

type___KeywordPlanKeywordHistoricalMetrics = KeywordPlanKeywordHistoricalMetrics



from typing import Any, Optional

from google.ads.google_ads.v3.proto.services import (
    asset_service_pb2_grpc as asset_service_pb2_grpc,
)

class AssetServiceGrpcTransport:
    def __init__(
        self,
        channel: Optional[Any] = ...,
        credentials: Optional[Any] = ...,
        address: str = ...,
    ) -> None: ...
    @classmethod
    def create_channel(
        cls, address: str = ..., credentials: Optional[Any] = ..., **kwargs: Any
    ): ...
    @property
    def channel(self): ...
    @property
    def get_asset(self): ...
    @property
    def mutate_assets(self): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserDataErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserDataErrorValue = typing___NewType("UserDataErrorValue", builtin___int)
    type___UserDataErrorValue = UserDataErrorValue
    UserDataError: _UserDataError
    class _UserDataError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserDataErrorEnum.UserDataErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UserDataErrorEnum.UserDataErrorValue, 0)
        UNKNOWN = typing___cast(UserDataErrorEnum.UserDataErrorValue, 1)
        OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED = typing___cast(
            UserDataErrorEnum.UserDataErrorValue, 2
        )
        TOO_MANY_USER_IDENTIFIERS = typing___cast(
            UserDataErrorEnum.UserDataErrorValue, 3
        )
        USER_LIST_NOT_APPLICABLE = typing___cast(
            UserDataErrorEnum.UserDataErrorValue, 4
        )
    UNSPECIFIED = typing___cast(UserDataErrorEnum.UserDataErrorValue, 0)
    UNKNOWN = typing___cast(UserDataErrorEnum.UserDataErrorValue, 1)
    OPERATIONS_FOR_CUSTOMER_MATCH_NOT_ALLOWED = typing___cast(
        UserDataErrorEnum.UserDataErrorValue, 2
    )
    TOO_MANY_USER_IDENTIFIERS = typing___cast(UserDataErrorEnum.UserDataErrorValue, 3)
    USER_LIST_NOT_APPLICABLE = typing___cast(UserDataErrorEnum.UserDataErrorValue, 4)
    type___UserDataError = UserDataError
    def __init__(self,) -> None: ...

type___UserDataErrorEnum = UserDataErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.offline_user_data_pb2 import (
    CustomerMatchUserListMetadata as google___ads___googleads___v4___common___offline_user_data_pb2___CustomerMatchUserListMetadata,
    UserData as google___ads___googleads___v4___common___offline_user_data_pb2___UserData,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UploadUserDataRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserDataOperation
    ]: ...
    @property
    def customer_match_user_list_metadata(
        self,
    ) -> google___ads___googleads___v4___common___offline_user_data_pb2___CustomerMatchUserListMetadata: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[type___UserDataOperation]
        ] = None,
        customer_match_user_list_metadata: typing___Optional[
            google___ads___googleads___v4___common___offline_user_data_pb2___CustomerMatchUserListMetadata
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "metadata",
            b"metadata",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "customer_match_user_list_metadata",
            b"customer_match_user_list_metadata",
            "metadata",
            b"metadata",
            "operations",
            b"operations",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["metadata", b"metadata"]
    ) -> typing_extensions___Literal["customer_match_user_list_metadata"]: ...

type___UploadUserDataRequest = UploadUserDataRequest

class UserDataOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v4___common___offline_user_data_pb2___UserData: ...
    @property
    def remove(
        self,
    ) -> google___ads___googleads___v4___common___offline_user_data_pb2___UserData: ...
    def __init__(
        self,
        *,
        create: typing___Optional[
            google___ads___googleads___v4___common___offline_user_data_pb2___UserData
        ] = None,
        remove: typing___Optional[
            google___ads___googleads___v4___common___offline_user_data_pb2___UserData
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create", "remove"]: ...

type___UserDataOperation = UserDataOperation

class UploadUserDataResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def upload_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def received_operations_count(
        self,
    ) -> google___protobuf___wrappers_pb2___Int32Value: ...
    def __init__(
        self,
        *,
        upload_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        received_operations_count: typing___Optional[
            google___protobuf___wrappers_pb2___Int32Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "received_operations_count",
            b"received_operations_count",
            "upload_date_time",
            b"upload_date_time",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "received_operations_count",
            b"received_operations_count",
            "upload_date_time",
            b"upload_date_time",
        ],
    ) -> None: ...

type___UploadUserDataResponse = UploadUserDataResponse
